.. _api:

API Docs
========

.. module:: flask_restful


.. autofunction:: marshal
.. autofunction:: marshal_with
.. autofunction:: marshal_with_field
.. autofunction:: abort


Api
---
.. autoclass:: Api
   :members:

    .. automethod:: unauthorized

.. autoclass:: Resource
   :members:

ReqParse
--------
.. module:: reqparse

.. autoclass:: RequestParser
   :members:

.. autoclass:: Argument
   :members:

   .. automethod:: __init__

Fields
------
.. automodule:: fields
   :members:
   :undoc-members:

Inputs
------
.. automodule:: inputs
   :members:
   :undoc-members:
